@@ -32,7 +32,6 @@ namespace
 {
   DECLARE_LOGGER(logger, "nux.inputmethod.ibus");
 }
-
   std::vector<Event> IBusIMEContext::hotkeys_;
 
   IBusBus* IBusIMEContext::bus_ = NULL;
@@ -44,10 +43,15 @@ namespace
     , is_focused_(false)
   {
     // init ibus
-    if (!bus_)
+    if (!G_OBJECT(bus_))
     {
       ibus_init();
       bus_ = ibus_bus_new();
+      g_object_add_weak_pointer(G_OBJECT(bus_), reinterpret_cast<gpointer*>(&bus_));
+    }
+    else
+    {
+      g_object_ref(bus_);
     }
 
     // connect bus signals
@@ -69,6 +73,7 @@ namespace
     DestroyContext();
     g_signal_handlers_disconnect_by_data(bus_, this);
     g_object_unref(cancellable_);
+    g_object_unref(bus_);
   }
 
   void IBusIMEContext::Focus()
@@ -503,6 +508,7 @@ namespace
       hotkeys_ = ParseIBusHotkeys(keybindings);
 
       g_variant_unref(val);
+      g_free(keybindings);
     }
   }
 
