@@ -179,6 +179,7 @@ namespace nux
     , key_nav_mode_(false)
     , lose_key_focus_on_key_nav_direction_up_(true)
     , lose_key_focus_on_key_nav_direction_down_(true)
+    , cursor_visible_on_key_focus_only_(false)
   {
     cairo_font_options_set_antialias(font_options_, CAIRO_ANTIALIAS_SUBPIXEL);
     cairo_font_options_set_hint_style(font_options_, CAIRO_HINT_STYLE_FULL);
@@ -241,7 +242,7 @@ namespace nux
     return result;
   }
 
-  void TextEntry::GeometryChanged()
+  void TextEntry::GeometryChanged(bool /*position_has_changed*/, bool /*size_has_changed*/)
   {
       update_canvas_ = true;
       View::GeometryChanged(true, true);
@@ -825,7 +826,7 @@ namespace nux
     }
   }
 
-  Color const& TextEntry::GetTextColor() const
+  Color TextEntry::GetTextColor() const
   {
     return _text_color;
   }
@@ -884,7 +885,7 @@ namespace nux
         need_im_reset_ = true;
 #if defined(USE_X11)
         ime_->Focus();
-        nux::GetWindowThread()->GetGraphicsDisplay().XICFocus();
+        nux::GetWindowThread()->XICFocus(this);
 #endif
         //gtk_im_context_focus_in(im_context_);
         //UpdateIMCursorLocation();
@@ -907,13 +908,20 @@ namespace nux
         need_im_reset_ = true;
 #if defined(USE_X11)
         ime_->Blur();
-        nux::GetWindowThread()->GetGraphicsDisplay().XICUnFocus();
+        nux::GetWindowThread()->XICUnFocus();
 #endif
         //gtk_im_context_focus_out(im_context_);
       }
       cursor_visible_ = false; // hide cursor when losing focus
       selection_changed_ = true;
       cursor_moved_ = true;
+
+      if (cursor_visible_on_key_focus_only_ && cursor_blink_timer_)
+      {
+        g_source_remove(cursor_blink_timer_);
+        cursor_blink_timer_ = 0;
+      }
+
       // Don't adjust scroll.
       QueueRefresh(true, false);
     }
@@ -1033,6 +1041,35 @@ namespace nux
     }
   }
 
+  void TextEntry::PreeditStarted()
+  {
+    ime_active_ = true;
+  }
+
+  void TextEntry::UpdatePreedit(std::string const& preedit, int cursor)
+  {
+    preedit_ = preedit;
+    preedit_cursor_ = cursor;
+    QueueRefresh(true, true);
+  }
+
+  void TextEntry::UpdatePreeditAttribs(PangoAttrList* list)
+  {
+    if (preedit_attrs_)
+    {
+      pango_attr_list_unref(preedit_attrs_);
+      preedit_attrs_ = NULL;
+    }
+
+    preedit_attrs_ = list;
+  }
+
+  void TextEntry::ClearPreedit()
+  {
+    ResetPreedit();
+    QueueRefresh(true, true);
+  }
+
   void TextEntry::DrawText(CairoGraphics *canvas)
   {
     PangoLayout *layout = EnsureLayout();
@@ -1115,6 +1152,9 @@ namespace nux
 
   void TextEntry::QueueCursorBlink()
   {
+    if (cursor_visible_on_key_focus_only_ && !focused_)
+      return;
+
     if (!cursor_blink_timer_)
       cursor_blink_timer_ = g_timeout_add(kCursorBlinkTimeout,
                                           (GSourceFunc)&CursorBlinkCallback,
@@ -2488,6 +2528,41 @@ namespace nux
     return lose_key_focus_on_key_nav_direction_down_;
   }
 
+  void TextEntry::SetToggleCursorVisibilityOnKeyFocus(bool b)
+  {
+    if (cursor_visible_on_key_focus_only_ == b)
+      return;
+
+    cursor_visible_on_key_focus_only_ = b;
+
+    if (cursor_visible_on_key_focus_only_)
+    {
+      if (!focused_)
+      {
+        if (cursor_blink_timer_)
+        {
+          g_source_remove(cursor_blink_timer_);
+          cursor_blink_timer_ = 0;
+        }
+
+        cursor_visible_ = false;
+        QueueDraw();
+      }
+    }
+    else
+    {
+      if (!focused_)
+      {
+        QueueCursorBlink();
+      }
+    }
+  }
+
+  bool TextEntry::GetToggleCursorVisibilityOnKeyFocus() const
+  {
+    return cursor_visible_on_key_focus_only_;
+  }
+
   bool TextEntry::IsInTextInputMode() const
   {
     return text_input_mode_;
