@@ -49,7 +49,7 @@ namespace nux
 
   }
 
-  VLayout::VLayout(NString name, NUX_FILE_LINE_DECL)
+  VLayout::VLayout(std::string name, NUX_FILE_LINE_DECL)
     : LinearLayout(NUX_FILE_LINE_PARAM)
   {
     m_name = name;
@@ -363,10 +363,6 @@ namespace nux
         if (!(*it)->IsVisible())
           continue;
 
-        bool larger_height  = false;
-        bool smaller_height = false;
-        bool smaller_width  = false;
-        bool larger_width   = false;
         int ret = 0;
         
         if (((*it)->IsLayout() || (*it)->IsView()) /*&& ((*it)->IsLayoutDone() == false)*/ /*&& ((*it)->GetScaleFactor() != 0)*/)
@@ -375,10 +371,10 @@ namespace nux
           ret = (*it)->ComputeContentSize();
           Geometry post_geo = (*it)->GetGeometry();
 
-          larger_width    = (pre_geo.width < post_geo.width)    ? true : false;
-          smaller_width   = (pre_geo.width > post_geo.width)    ? true : false;
-          larger_height   = (pre_geo.height < post_geo.height)  ? true : false;
-          smaller_height  = (pre_geo.height > post_geo.height)  ? true : false;
+          bool larger_width    = pre_geo.width < post_geo.width;
+          bool smaller_width   = pre_geo.width > post_geo.width;
+          bool larger_height   = pre_geo.height < post_geo.height;
+          bool smaller_height  = pre_geo.height > post_geo.height;
 
           if ((larger_height || smaller_height) && ((*it)->IsLayoutDone() == false))
           {
@@ -428,7 +424,7 @@ namespace nux
           {
             if (m_contentWidth < element_width)
             {
-              if (m_contentWidth < GetMaximumHeight())
+              if (m_contentWidth < GetMaximumWidth())
               {
                 // An element is larger than the layout width and the layout has not reach its maximum width yet.
                 m_contentWidth = element_width;
@@ -456,7 +452,9 @@ namespace nux
       // m_contentWidth + (left_padding_ + right_padding_);
       SetBaseWidth(m_contentWidth + (left_padding_ + right_padding_));
 
-      int temp = m_contentWidth;
+      // Get back the Width after it has been bounded by [minWidth, maxWidth] in the preceeding call to SetBaseWidth.
+      // Then deduce the width of the content.
+      int temp = GetWidth() - (left_padding_ + right_padding_);
       std::vector<int>::iterator IntIterator = FullSizeUnadjusted.begin();
 
       for (IntIterator = FullSizeUnadjusted.begin(); IntIterator != FullSizeUnadjusted.end(); ++IntIterator)
@@ -523,7 +521,7 @@ namespace nux
     return size_compliance;
   }
 
-  void VLayout::VLayoutManagement(int width, int height)
+  void VLayout::VLayoutManagement(int /* width */, int height)
   {
     bool need_recompute = false;
 
