@@ -27,8 +27,10 @@
 
 #if defined(NUX_OS_WINDOWS)
   #include "VirtualKeyCodes.h"
-#elif defined(NUX_OS_LINUX)
+#elif defined(USE_X11)
   #include "VirtualKeyCodesX11.h"
+#elif defined(NO_X11)
+  #include "VirtualKeyCodes.h"
 #else
   #error VirtualKeyCode file not Implemented.
 #endif
@@ -133,6 +135,8 @@ namespace nux
 #define NUX_EVENT_BUTTON4           0x00080000
 
 #define NUX_EVENT_MOUSEWHEEL        0x00100000
+// Describes the event as the first press in the double click event.
+#define NUX_STATE_FIRST_EVENT       0x00200000
 // These flags describe the state of the mouse buttons.
 // They persist over several frame until the mouse buttons change state.
 // Go in mouse_state.
@@ -211,6 +215,9 @@ namespace nux
     EVENT_MOUSE_MOVE,
     EVENT_MOUSE_DOUBLECLICK,
     EVENT_MOUSE_WHEEL,
+    EVENT_MOUSE_CANCEL, /*!< InputArea lost ownership over a pressed mouse. Any
+                             changes caused by the previous EVENT_MOUSE_PRESS
+                             should be undone. */
     EVENT_KEY_DOWN,
     EVENT_KEY_UP,
     EVENT_WINDOW_SIZE_CONFIGURATION,
@@ -393,9 +400,7 @@ namespace nux
 #if defined(NUX_OS_WINDOWS)
     int win32_keycode; // Not used. Just a place holder.
     int win32_keysym;
-#endif
-
-#if defined(NUX_OS_LINUX)
+#elif defined(USE_X11)
     Time          x11_timestamp;  //!< X11 timestamp.
     Window        x11_window;     //!< X11 window.
     unsigned int  x11_key_state;  //!< X11 key state (xevent.xkey.state).
@@ -406,6 +411,7 @@ namespace nux
     int wheel_delta;              //!< Wheel delta.
 
     char            text[NUX_EVENT_TEXT_BUFFER_SIZE];
+    char*           dtext;            //!< Dynamically allocated
     unsigned long   key_modifiers;    //!< Key modifiers. A bitwise inclusive OR of values in KeyModifier.
     unsigned long   mouse_state;
     unsigned short  key_repeat_count; //!< Number of time a key is repeated;
