@@ -115,31 +115,37 @@ namespace nux
   typedef enum
   {
     LAYER_BLEND_MODE_NORMAL,
-    LAYER_BLEND_MODE_LIGHTEN,
+    // Darken Modes
     LAYER_BLEND_MODE_DARKEN,
     LAYER_BLEND_MODE_MULTIPLY,
-    LAYER_BLEND_MODE_AVERAGE,
-    LAYER_BLEND_MODE_ADD,
-    LAYER_BLEND_MODE_SUBTRACT,
-    LAYER_BLEND_MODE_DIFFERENCE,
-    LAYER_BLEND_MODE_NEGATION,
-    LAYER_BLEND_MODE_EXCLUSION,
+    LAYER_BLEND_MODE_COLOR_BURN,
+    LAYER_BLEND_MODE_LINEAR_BURN,
+    // Lighten Modes
+    LAYER_BLEND_MODE_LIGHTEN,
     LAYER_BLEND_MODE_SCREEN,
+    LAYER_BLEND_MODE_COLOR_DODGE,
+    LAYER_BLEND_MODE_LINEAR_DODGE,
+    // Constrast Modes
     LAYER_BLEND_MODE_OVERLAY,
     LAYER_BLEND_MODE_SOFT_LIGHT,
     LAYER_BLEND_MODE_HARD_LIGHT,
-    LAYER_BLEND_MODE_COLOR_DODGE,
-    LAYER_BLEND_MODE_LINEAR_DODGE,
-    LAYER_BLEND_MODE_COLOR_BURN,
-    LAYER_BLEND_MODE_LINEAR_BLUR,
-    LAYER_BLEND_MODE_LINEAR_LIGHT,
     LAYER_BLEND_MODE_VIVID_LIGHT,
+    LAYER_BLEND_MODE_LINEAR_LIGHT,
     LAYER_BLEND_MODE_PIN_LIGHT,
     LAYER_BLEND_MODE_HARD_MIX,
+    // Inversion Modes
+    LAYER_BLEND_MODE_DIFFERENCE,
+    LAYER_BLEND_MODE_EXCLUSION,
+    // Cancellation Modes
+    LAYER_BLEND_MODE_SUBTRACT,
+    // Others
+    LAYER_BLEND_MODE_AVERAGE,
+    LAYER_BLEND_MODE_ADD,
+    LAYER_BLEND_MODE_NEGATION,
     LAYER_BLEND_MODE_REFLECT,
     LAYER_BLEND_MODE_GLOW,
     LAYER_BLEND_MODE_PHOENIX,
-    LAYER_BLEND_MODE_OPACITY,
+    //LAYER_BLEND_MODE_OPACITY,
     LAYER_BLEND_MODE_LAST
   } LayerBlendMode;
 
@@ -269,6 +275,7 @@ namespace nux
       ObjectPtr<IOpenGLBaseTexture>& src_device_texture,
       TexCoordXForm& texxform0, const Color& c0);
 
+#ifndef NUX_OPENGLES_20
     // ASM
     void QRP_ASM_1Tex(int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> Tex0, TexCoordXForm& texxform, const Color& color0);
     void QRP_ASM_1TexPremultiply(int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> Tex0, TexCoordXForm& texxform, const Color& color0);
@@ -387,7 +394,7 @@ namespace nux
       ObjectPtr<IOpenGLBaseTexture>& dst_device_texture,
       ObjectPtr<IOpenGLBaseTexture>& src_device_texture,
       TexCoordXForm& texxform0, const Color& c0);
-
+#endif
     // GLSL
 
     void QRP_GLSL_1Tex(int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> DeviceTexture, TexCoordXForm& texxform, const Color& c0);
@@ -427,6 +434,8 @@ namespace nux
     void QRP_GLSL_VerticalGauss   (int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform, const Color& c0, float sigma = 1.0f);
     void QRP_GLSL_HorizontalHQGauss(int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform, const Color& c0, float sigma = 1.0f);
     void QRP_GLSL_VerticalHQGauss   (int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform, const Color& c0, float sigma = 1.0f);
+    void QRP_GLSL_HorizontalLSGauss(int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform, const Color& c0, float sigma = 1.0f);
+    void QRP_GLSL_VerticalLSGauss   (int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform, const Color& c0, float sigma = 1.0f);
     void QRP_GLSL_ColorMatrix     (int x, int y, int width, int height, ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform, const Color& c0, Matrix4 color_matrix, Vector4 offset);
 
     /*!
@@ -443,6 +452,13 @@ namespace nux
       ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform,
       const Color& c0,
       float sigma = 1.0f, int num_pass = 1);
+    
+    ObjectPtr<IOpenGLBaseTexture> QRP_GLSL_GetLSBlurTexture(
+      int x, int y,
+      int buffer_width, int buffer_height,
+      ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform,
+      const Color& c0,
+      float sigma = 1.0f, int num_pass = 1);
 
     ObjectPtr<IOpenGLBaseTexture> QRP_GLSL_GetAlphaTexture(
       ObjectPtr<IOpenGLBaseTexture> device_texture, TexCoordXForm& texxform,
@@ -473,6 +489,12 @@ namespace nux
       int buffer_width, int buffer_height,
       FxStructure* fx_structure, TexCoordXForm& texxform,
       const Color& c0, float sigma = 1.0f, int num_pass = 1);
+    
+   void QRP_GLSL_GetLSBlurFx(
+    int x, int y,
+    int buffer_width, int buffer_height,
+    FxStructure *fx_structure, TexCoordXForm &texxform,
+    const Color& c0, float sigma = 1.0f, int num_pass = 1);
 
     void QRP_GLSL_DisturbedTexture(
       int x, int y, int width, int height,
@@ -511,13 +533,13 @@ namespace nux
     //////////////////////
 
     mutable std::vector<Rect> ClippingRect;
-    void PushClippingRectangle(Rect rect);
+    void PushClippingRectangle(Rect const& rect);
     void PopClippingRectangle();
     void EmptyClippingRegion();
     //! Set the clipping according to the clipping rectangle stack.
     void ApplyClippingRectangle();
-    
-    void SetGlobalClippingRectangle(Rect rect);
+
+    void SetGlobalClippingRectangle(Rect const& rect);
     void DisableGlobalClippingRectangle();
 
     //! Bypass the clipping rectangle stack and set a different clipping rectangle region.
@@ -531,7 +553,7 @@ namespace nux
 
     Rect GetClippingRegion() const;
     int GetNumberOfClippingRegions() const;
-    
+
     void AddClipOffset(int x, int y);  //!< Deprecated. Use PushClipOffset.
     void PushClipOffset(int x, int y);
     void PopClipOffset();
@@ -570,7 +592,7 @@ namespace nux
     */
     void SetScissorOffset(int x, int y);
 
-    Rect GetScissorRect();
+    Rect const& GetScissorRect() const;
     void EnableScissoring(bool b);
 
 
@@ -579,17 +601,19 @@ namespace nux
 //     Rect GetImageGeometry(UXStyleImageRef style);
 //     std::list<PainterImage*> m_PainterImageList;
 
-    int RenderColorText(ObjectPtr<FontTexture> Font, int x, int y, const NString& Str,
+    int RenderColorText(ObjectPtr<FontTexture> Font, int x, int y, std::string const& Str,
                          const Color& TextColor,
                          bool WriteAlphaChannel,
                          int NumCharacter);
 
-    int RenderColorTextLineStatic(ObjectPtr<FontTexture> Font, const PageBBox& pageSize, const NString& Str,
+    int RenderColorTextLineStatic(ObjectPtr<FontTexture> Font, const PageBBox& pageSize,
+                                  std::string const& Str,
                                    const Color& TextColor,
                                    bool WriteAlphaChannel,
                                    TextAlignment alignment);
 
-    int RenderColorTextLineEdit(ObjectPtr<FontTexture> Font, const PageBBox& pageSize, const NString& Str,
+    int RenderColorTextLineEdit(ObjectPtr<FontTexture> Font, const PageBBox& pageSize,
+                                std::string const& Str,
                                  const Color& TextColor,
                                  bool WriteAlphaChannel,
                                  const Color& SelectedTextColor,
@@ -660,15 +684,15 @@ namespace nux
 
     GpuRenderStates& GetRenderStates()
     {
-      return *_graphics_display.m_DeviceFactory->_gpu_render_states;
+      return *_graphics_display.m_DeviceFactory->gpu_render_states_;
     }
     void ResetRenderStates()
     {
-      _graphics_display.m_DeviceFactory->_gpu_render_states->ResetStateChangeToDefault();
+      _graphics_display.m_DeviceFactory->gpu_render_states_->ResetStateChangeToDefault();
     }
     void VerifyRenderStates()
     {
-      _graphics_display.m_DeviceFactory->_gpu_render_states->CheckStateChange();
+      _graphics_display.m_DeviceFactory->gpu_render_states_->CheckStateChange();
     }
 
     ObjectPtr<FontTexture> GetFont();
@@ -777,42 +801,52 @@ namespace nux
     */
     int BlendStackDepth();
 
-    //! Blends a color over a texture layer.
+    //! Blends a color layer over a texture.
     /*!
         Blends a color over a texture layer.
 
-        @param device_texture Background layer.
-        @param foreground_color Foreground layer.
+        @param bkg_device_texture Background texture.
+        @param frg_color Foreground color.
     */
-    void QRP_GLSL_ColorBlendOverTex(int x, int y, int width, int height,
-          ObjectPtr<IOpenGLBaseTexture> bkg_device_texture, TexCoordXForm& texxform, const Color& color0,
-          const Color& foreground_color,
-          LayerBlendMode layer_blend_mode);
+    void QRP_GLSL_ColorLayerOverTexture(int x, int y, int width, int height,
+      ObjectPtr<IOpenGLBaseTexture> bkg_device_texture, TexCoordXForm& bkg_texxform, const Color& bkg_color,
+      const Color& frg_color,
+      LayerBlendMode layer_blend_mode);
 
-    //! Blends a texture over a color layer.
+    //! Blends a texture layer over a color.
     /*!
         Blends a texture over a color layer.
 
-        @param background_color Background layer.
-        @param device_texture Foreground layer.
+        @param bkg_color Background color.
+        @param frg_device_texture Foreground texture.
     */
-    void QRP_GLSL_TexBlendOverColor(int x, int y, int width, int height,
-          const Color& background_color,
-          ObjectPtr<IOpenGLBaseTexture> frg_device_texture, TexCoordXForm& texxform0, const Color& color0,
-          LayerBlendMode layer_blend_mode);
+    void QRP_GLSL_TextureLayerOverColor(int x, int y, int width, int height,
+      const Color& bkg_color,
+      ObjectPtr<IOpenGLBaseTexture> frg_device_texture, TexCoordXForm& frg_texxform, const Color& frg_color,
+      LayerBlendMode layer_blend_mode);
 
-    //! Blends a texture over a texture layer.
+    //! Blends a texture layer over a texture.
     /*!
-        Blends a texture over a texture layer.
+        Uses a layer blending operation to render two textures.
 
-        @param bkg_device_texture Background layer.
-        @param frg_device_texture Foreground layer.
+        @param bkg_device_texture Background texture layer.
+        @param frg_device_texture Foreground texture layer.
     */
-    void QRP_GLSL_TexBlendOverTex(int x, int y, int width, int height,
-          ObjectPtr<IOpenGLBaseTexture> bkg_device_texture, TexCoordXForm& texxform0, const Color& color0,
-          ObjectPtr<IOpenGLBaseTexture> frg_device_texture, TexCoordXForm& texxform1, const Color& color1,
-          LayerBlendMode layer_blend_mode);
+    void QRP_GLSL_TextureLayerOverTexture(int x, int y, int width, int height,
+      ObjectPtr<IOpenGLBaseTexture> bkg_device_texture, TexCoordXForm& bkg_texxform, const Color& bkg_color,
+      ObjectPtr<IOpenGLBaseTexture> frg_device_texture, TexCoordXForm& frg_texxform, const Color& frg_color,
+      LayerBlendMode layer_blend_mode);
 
+    //! Blends a color layer over a color.
+    /*!
+        Uses a layer blending operation to render two colors.
+        @param bkg_color Background color layer.
+        @param frg_color Foreground color layer.
+    */
+    void QRP_GLSL_ColorLayerOverColor(int x, int y, int width, int height,
+      const Color& bkg_color,
+      const Color& frg_color,
+      LayerBlendMode layer_blend_mode);
 
   private:
 
@@ -823,6 +857,9 @@ namespace nux
 
     //! Helper function to compute a Gaussian filter weights
     void GaussianWeights(float **weights, float sigma, unsigned int num_tap);
+    
+    int LinearSampleGaussianWeights(std::vector<float>& weights, std::vector<float>& offsets, 
+                                                  float sigma);
 
     //! Helper function to set an fbo
     void SetFrameBufferHelper(
@@ -990,6 +1027,14 @@ namespace nux
     void InitSLVerticalHQGaussFilter(int sigma);
     //! Gauss vertical filter.
     ObjectPtr<IOpenGLShaderProgram> _vertical_hq_gauss_filter_prog[NUX_MAX_GAUSSIAN_SIGMA];
+    
+    void InitSLHorizontalLSGaussFilter(int k);
+    //! Gauss horizontal filter.
+    ObjectPtr<IOpenGLShaderProgram> _horizontal_ls_gauss_filter_prog[NUX_MAX_GAUSSIAN_SIGMA];
+
+    void InitSLVerticalLSGaussFilter(int k);
+    //! Gauss vertical filter.
+    ObjectPtr<IOpenGLShaderProgram> _vertical_ls_gauss_filter_prog[NUX_MAX_GAUSSIAN_SIGMA];
 
     void InitSLColorMatrixFilter();
     //! Color matrix filter.
@@ -1013,13 +1058,15 @@ namespace nux
     ObjectPtr<IOpenGLShaderProgram> blend_tex_color_prog_[LAYER_BLEND_MODE_LAST];
     ObjectPtr<IOpenGLShaderProgram> blend_color_tex_prog_[LAYER_BLEND_MODE_LAST];
     ObjectPtr<IOpenGLShaderProgram> blend_tex_tex_prog_[LAYER_BLEND_MODE_LAST];
+    ObjectPtr<IOpenGLShaderProgram> blend_color_color_prog_[LAYER_BLEND_MODE_LAST];
     
-    const char* const GetBlendModeBlendFunc(LayerBlendMode layer_blend_mode);
-    const char* const GetBlendModeString(LayerBlendMode layer_blend_mode);
+    std::string GetBlendModeBlendFunc(LayerBlendMode layer_blend_mode);
+    std::string GetBlendModeString(LayerBlendMode layer_blend_mode);
     
-    ObjectPtr <IOpenGLShaderProgram> GetColorBlendOverTexProgram(LayerBlendMode layer_blend_mode);
-    ObjectPtr <IOpenGLShaderProgram> GetTexBlendOverColorProgram(LayerBlendMode layer_blend_mode);
-    ObjectPtr <IOpenGLShaderProgram> GetBlendTexTexProgram(LayerBlendMode layer_blend_mode);
+    ObjectPtr<IOpenGLShaderProgram> GetColorBlendOverTexProgram(LayerBlendMode layer_blend_mode);
+    ObjectPtr<IOpenGLShaderProgram> GetTextureLayerOverColorProgram(LayerBlendMode layer_blend_mode);
+    ObjectPtr<IOpenGLShaderProgram> GetTextureLayerOverTextureProgram(LayerBlendMode layer_blend_mode);
+    ObjectPtr<IOpenGLShaderProgram> GetColorLayerOverColorProgram(LayerBlendMode layer_blend_mode);
 
 
 
